# ECE 106: Electricity and Magnetism

## MATH 117 review

!!! definition
    A definite integral is composed of:
    
    - the **upper limit**, $b$,
    - the **lower limit**, $a$,
    - the **integrand**, $f(x)$, and
    - the **differential element**, $dx$.

$$\int^b_a f(x)\ dx$$

The original function **cannot be recovered** from the result of a definite integral unless it is known that $f(x)$ is a constant.

## N-dimensional integrals

Much like how $dx$ represents an infinitely small line, $dx\cdot dy$ represents an infinitely small rectangle. This means that the surface area of an object can be expressed as:

$$dS=dx\cdot dy$$

Therefore, the area of a function can be expressed as:

$$S=\int^x_0\int^y_0 dy\ dx$$

where $y$ is usually equal to $f(x)$, changing on each iteration.

!!! example
    The area of a circle can be expressed as $y=\pm\sqrt{r^2-x^2}$. This can be reduced to $y=2\sqrt{r^2-x^2}$ because of the symmetry of the equation.
    
    $$
    \begin{align*}
    A&=\int^r_0\int^{\sqrt{r^2-x^2}}_0 dy\ dx \\
    &=\int^r_0\sqrt{r^2-x^2}\ dx
    \end{align*}
    $$

!!! warning
    Similar to parentheses, the correct integral squiggly must be paired with the correct differential element.

These rules also apply for a system in three dimensions:

| Vector | Length | Area | Volume | 
| --- | --- | --- | --- |
| $x$ | $dx$ | $dx\cdot dy$ | $dx\cdot dy\cdot dz$ |
| $y$ | $dy$ | $dy\cdot dz$ | |
| $z$ | $dz$ | $dx\cdot dz$ | |

Although differential elements can be blindly used inside and outside an object (e.g., area), the rules break down as the **boundary** of an object is approached (e.g., perimeter). Applying these rules to determine an object's perimeter will result in the incorrect deduction that $\pi=4$.

Therefore, further approximations can be made using the Pythagorean theorem to represent the perimeter.

$$dl=\sqrt{(dx^2) + (dy)^2}$$

### Polar coordinates

Please see [MATH 115: Linear Algebra#Polar form](/1a/math115/#polar-form) for more information.

In polar form, the difference in each "rectangle" side length is slightly different.

| Vector | Length difference |
| --- | --- |
| $\hat r$ | $dr$ |
| $\hat\phi$ | $rd\phi$ |

Therefore, the change in surface area can be approximated to be a rectangle and is equal to:

$$dS=(dr)(rd\phi)$$

!!! example
    The area of a circle can be expressed as $A=\int^{2\pi}_0\int^R_0 r\ dr\ d\phi$.
    
    $$
    \begin{align*}
    A&=\int^{2\pi}_0\frac{1}{2}R^2\ d\phi \\
    &=\pi R^2
    \end{align*}
    $$

If $r$ does not depend on $d\phi$, part of the integral can be pre-evaluated:

$$
\begin{align*}
dS&=\int^{2\pi}_{\phi=0} r\ dr\ d\phi \\
dS^\text{ring}&=2\pi r\ dr
\end{align*}
$$

So long as the variables are independent of each other, their order does not matter. Otherwise, the dependent variable must be calculated first.


!!! tip
    There is a shortcut for integrals of cosine and sine squared, **so long as $a=0$ and $b$ is a multiple of $\frac\pi 2$**:
    
    $$
    \int^b_a\cos^2\phi=\frac{b-a}{2} \\
    \int^b_a\sin^2\phi=\frac{b-a}{2}
    $$

The side length of a curve is as follows:

$$dl=\sqrt{(dr^2+(rd\phi)^2}$$

!!! example
    The side length of the curve $r=e^\phi$ (Archimedes' spiral) from $0$ to $2\pi$:
    
    \begin{align*}
    dl &=d\phi\sqrt{\left(\frac{dr}{d\phi}\right)^2 + r^2} \\
    \tag{$\frac{dr}{d\phi}=e^\phi$}&=d\phi\sqrt{e^{2\phi}+r^2} \\
    &=????????
    \end{align*}

Polar **volume** is the same as Cartesian volume:

$$dV=A\ dr$$

!!! example
    For a cylinder of radius $R$ and height $h$:
    
    $$
    \begin{align*}
    dV&=\pi R^2\ dr \\
    V&=\int^h_0 \pi R^2\ dr \\
    &=\pi R^2 h
    \end{align*}
    $$

### Moment of inertia

The **mass distribution** of an object varies depending on its surface density $\rho_s$. In objects with uniformly distributed mass, the surface density is equal to the total mass over the total area.

$$dm=\rho_s\ dS$$

The formula for the **moment of inertia** of an object is as follows, where $r_\perp$ is the distance from the axis of rotation:

$$dI=(r_\perp)^2dm$$

!!! example
    In a uniformly distributed disk rotating about the origin like a CD with mass $M$ and radius $R$:
    
    $$
    \begin{align*}
    \rho_s &= \frac{M}{\pi R^2} \\
    dm &= \rho_s\ r\ dr\ d\phi \\
    dI &=r^2\ dm \\
    &= r^2\rho_s r\ dr\ d\phi \\
    &= \rho_s r^3dr\ d\phi \\
    I &=\rho_s\int^{2\pi}_{\phi=0}\int^R_{r=0} r^3dr\ d\phi \\
    &= \rho_s\int^{2\pi}_{\phi=0}\frac{1}{4}R^4d\phi \\
    &= \rho_s\frac{1}{2}\pi R^4 \\
    &= \frac 1 2 MR^2
    \end{align*}
    $$

## Electrostatics

!!! definition
    - The **polarity** of a particle is whether it is positive or negative.

The law of **conservation of charge** states that electrons and charges cannot be created nor destroyed, such that the **net charge in a closed system stays the same**.

The law of **charge quantisation** states that charge is discrete — electrons have the lowest possible quantity.

Please see [SL Physics 1#Charge](/sph3u7/#charge) for more information.

**Coulomb's law** states that for point charges $Q_1, Q_2$ with distance from the first to the second $\vec R_{12}$:

$$\vec F_{12}=k\frac{Q_1Q_2}{||R_{12}||^2}\hat{R_{12}}$$
